pub async fn commit(input: GitCommitInput) -> Result<()>Expand description
NOTE: git:changed events are driven by frontend mutation invalidation (useGitCommit / useGitPush onSettled), not emitted from the backend.
pub async fn commit(input: GitCommitInput) -> Result<()>NOTE: git:changed events are driven by frontend mutation invalidation (useGitCommit / useGitPush onSettled), not emitted from the backend.