pub async fn summary(pool: &SqlitePool, days: i64) -> Result<RecallSummary>Expand description
Total local recall proof over the last days days.
pub async fn summary(pool: &SqlitePool, days: i64) -> Result<RecallSummary>Total local recall proof over the last days days.