pub enum DiffContextMode {
ReviewExtraction,
FixPr,
}Expand description
Caller intent for ordering records before fitting them into a budget.
Variants
ReviewExtraction
Prefer highly relevant files, then smaller files for broad review coverage.
FixPr
Prefer highly relevant files, then files with more changed lines, while still fitting smaller records first when otherwise tied.