Structs
- AddComment
Input - Ensure
Item Input - List
With Comments Input - Review
Comment IdInput - Review
Comment Metadata Record - Review
Comment Record - Review
Explainability Metadata Record - Review
Issue Snippet Record - Review
Item IdInput - Review
Item Record - Review
Item With Comments - Review
Project Input - Review
Source Input - Update
Item Status Input
Functions
- add_
comment - build_
explainability_ metadata - build_
review_ comment_ metadata - ensure_
item - format_
review_ issue_ comment - list_
by_ project - list_
by_ source - list_
by_ source_ with_ comments - list_
comments - list_
recent - List the most recent review items across all sources. Used by the TUI Reviews tab where the user wants a cross-source activity feed, not a per-source filter.
- list_
with_ comments - remove_
comment - remove_
item - update_
item_ status