pub enum RuleStatus {
Active,
Pending,
}Expand description
Lifecycle status for a row in the local skills table.
Active rows are served by MCP (load_rules_from_db_* filters); Pending
rows are unreviewed local memory drafts that are promoted before they
are served to agents.
Variants
Implementations